@@ -7,7 +7,7 @@ no warnings 'uninitialized';
 
 use Module::Load;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -38,7 +38,7 @@ although they may not be proper Unicode.
 =cut
 
 {
-    use open ':encoding(std)';
+    use open ':std';
     Module::Load::load('Geography::States');
 }
 
